@@ -39,6 +39,7 @@ Orbited.settings.hostname = document.domain
 Orbited.settings.port = (location.port.length > 0) ? location.port : 80
 Orbited.settings.protocol = 'http'
 Orbited.settings.log = false;
+Orbited.settings.streaming = false;
 Orbited.settings.HEARTBEAT_TIMEOUT = 6000
 Orbited.settings.POLL_INTERVAL = 2000
 Orbited.settings.pageLoggerHeight = '200px'
@@ -348,6 +349,9 @@ Orbited.system = Orbited.getLogger('system')
 Orbited.CometTransports = {}
 
 Orbited.util.chooseTransport = function() {
+    if (Orbited.settings.streaming == false) {
+        return Orbited.CometTransports.LongPoll;
+    }
     var choices = []
     for (var name in Orbited.CometTransports) {
         var transport = Orbited.CometTransports[name];
